<?php

namespace Drupal\graphql_address\Plugin\GraphQL\DataProducer;

use CommerceGuys\Addressing\Country\CountryRepositoryInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\graphql\Plugin\GraphQL\DataProducer\DataProducerPluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Address country repository plugin for GraphQL.
 *
 * @DataProducer(
 *   id = "graphql_address_country_repository",
 *   name = @Translation("Country Repository"),
 *   description = @Translation("Resolve the country_code into repository values."),
 *   produces = @ContextDefinition("string",
 *     label = @Translation("Country repository value")
 *   ),
 *   consumes = {
 *     "langcode" = @ContextDefinition("string",
 *       label = @Translation("An ISO 639-1 language code."),
 *       required = FALSE,
 *     ),
 *   }
 * )
 */
class AddressCountryRepository extends DataProducerPluginBase implements ContainerFactoryPluginInterface {

  /**
   * Country repository interface.
   *
   * @var \CommerceGuys\Addressing\Country\CountryRepositoryInterface
   */
  protected $countryRepository;

  /**
   * AddressCountryName constructor.
   *
   * @param array $configuration
   *   Configuration data.
   * @param string $plugin_id
   *   Plugin ID.
   * @param mixed $plugin_definition
   *   Plugin definition.
   * @param \CommerceGuys\Addressing\Country\CountryRepositoryInterface $country_repository
   *   Country repository interface.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, CountryRepositoryInterface $country_repository) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->countryRepository = $country_repository;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('address.country_repository')
    );
  }

  /**
   * Resolve address country repository based on langcode.
   *
   * @param string|null $langcode
   *   Language code.
   *
   * @return array
   *   List of address countries.
   */
  public function resolve(?string $langcode): array {
    return array_keys($this->countryRepository->getall($langcode));
  }

}
