<?php

namespace Drupal\graphql_address\Plugin\GraphQL\DataProducer;

use CommerceGuys\Addressing\AddressFormat\AddressFormatRepositoryInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\graphql\Plugin\GraphQL\DataProducer\DataProducerPluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Address format repository plugin for GraphQL.
 *
 * @DataProducer(
 *   id = "graphql_address_format_repository",
 *   name = @Translation("Format Repository"),
 *   description = @Translation("Resolve the country_code into repository values."),
 *   produces = @ContextDefinition("any",
 *     label = @Translation("Format repository value")
 *   ),
 *   consumes = {
 *     "country_code" = @ContextDefinition("string",
 *       label = @Translation("The format code.")
 *     ),
 *     "method" = @ContextDefinition("string",
 *       label = @Translation("The method to fetch the repository value.")
 *     ),
 *     "langcode" = @ContextDefinition("string",
 *       label = @Translation("An ISO 639-1 language code."),
 *       required = FALSE,
 *     ),
 *   }
 * )
 */
class AddressFormatRepository extends DataProducerPluginBase implements ContainerFactoryPluginInterface {

  /**
   * Format repository.
   *
   * @var \CommerceGuys\Addressing\AddressFormat\AddressFormatRepositoryInterface
   */
  protected $formatRepository;

  /**
   * AddressFormatName constructor.
   *
   * @param array $configuration
   *   Configuration data.
   * @param string $plugin_id
   *   Plugin ID.
   * @param mixed $plugin_definition
   *   Plugin definition.
   * @param \CommerceGuys\Addressing\AddressFormat\AddressFormatRepositoryInterface $format_repository
   *   Address format repository interface.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, AddressFormatRepositoryInterface $format_repository) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->formatRepository = $format_repository;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('address.address_format_repository')
    );
  }

  /**
   * Format subdivision data based on method name, country and language code.
   *
   * @param string $country_code
   *   Country code.
   * @param string $method
   *   FormatRepository Method name.
   *
   * @return mixed
   *   Format subdivision.
   */
  public function resolve(string $country_code, string $method) {
    $format = $this->formatRepository->get($country_code);
    return $format->$method();
  }

}
